@@ -2,30 +2,27 @@ from datetime import datetime
 
 import pytz
 
-from margot.data import Symbol, MargotDataFrame, Ratio
-from margot.data.column import cboe, alphavantage as av
-from margot.data.features import finance
-from margot.signals import Position, BaseAlgo
-from margot.backtest import BackTest
+from margot import Symbol, MargotDataFrame, Ratio, BaseAlgo, Position, BackTest
+from margot import finance, cboe, alphavantage as av
 
 
 class Index(Symbol):
     close = cboe.Column(time_series='close')
     sma = finance.SimpleMovingAverage(column='close',
-                                        window=3)
+                                      window=3)
 
 
 class Equity(Symbol):
     close = av.Column(time_series='adjusted_close')
-    log_returns = finance.LogReturns(column='close')
+    simple_returns = finance.SimpleReturns(column='close')
 
 
 class VXBasisDF(MargotDataFrame):
     vix = Index('VIX', trading_calendar='NYSE')
     vix3m = Index('VIX3M', trading_calendar='NYSE')
     ratio = Ratio(numerator=vix.close,
-                    denominator=vix3m.close,
-                    label='vxbasis')
+                  denominator=vix3m.close,
+                  label='vxbasis')
     ziv = Equity('ZIV', trading_calendar='NYSE')
 
 
@@ -35,9 +32,9 @@ class VXBasisTrade(BaseAlgo):
     def signal(self):
         if self.data.ratio.latest <= 1.0 and \
             self.data.vix.close.latest <= self.data.vix.sma.latest:
-            return [Position(symbol='ZIV', weight=1.0)]
+            return [Position('ZIV', 1.0, self.MOC)]
         else:
-            return [Position(symbol='ZIV', weight=0.0)]
+            return [Position('ZIV', 0.0, self.MOC)]
 
                     
 def test_simulation():
